using Frontend.Configuration;
using Microsoft.AspNetCore.Mvc.RazorPages;
using Nethereum.Web3;
using Nethereum.Web3.Accounts;

namespace Frontend.Pages;

public class IndexModel : PageModel
{
    private readonly ILogger<IndexModel> _logger;
    private readonly PoolV3Client _poolV3Client;
    private readonly ChainSettings _chainSettings;
    private readonly Account _account;
    private readonly Rebalancer _rebalancer;

    public IndexModel(ILogger<IndexModel> logger, Web3 web3, ChainSettings chainSettings, Account account, Rebalancer rebalancer)
    {
        _logger = logger;
        _poolV3Client = new PoolV3Client(web3, chainSettings, account);
        _chainSettings = chainSettings;
        _account = account;
        _rebalancer = rebalancer;
    }

    public void OnGet()
    {
        string? fromTokenAddress = null;
        string? toTokenAddress = null;
        decimal amount = 0;

        if (Request.Query.ContainsKey("swapROCToETH"))
        {
            fromTokenAddress = _chainSettings.TokenAddress;
            toTokenAddress = _chainSettings.WethTokenAddress;
            amount = decimal.Parse(Request.Query["swapROCToETH"]);

        }else if (Request.Query.ContainsKey("swapETHToROC"))
        {
            fromTokenAddress = _chainSettings.WethTokenAddress;
            toTokenAddress = _chainSettings.TokenAddress;
            amount = decimal.Parse(Request.Query["swapETHToROC"]);
        }
        if (amount > 0)
        {
            var amountRecieved = _poolV3Client.SwapAsync(fromTokenAddress!, toTokenAddress!, amount).Result;
        }

        if(Request.Query.ContainsKey("balancePool")){
            _rebalancer.MaintainPoolAsync().Wait();
        }
        if(Request.Query.ContainsKey("balanceReserves")){
            _rebalancer.MaintainLiquidReservesAsync().Wait();
        }
    }
}
